diff --git a/src/yuzu/main.cpp b/src/yuzu/main.cpp
index 53f11a9ac..18d161320 100644
--- a/src/yuzu/main.cpp
+++ b/src/yuzu/main.cpp
@@ -3626,8 +3626,8 @@ int main(int argc, char* argv[]) {
     QCoreApplication::setApplicationName(QStringLiteral("yuzu"));
 
 #ifdef _WIN32
-    // Increases the maximum open file limit to 4096
-    _setmaxstdio(4096);
+    // Increases the maximum open file limit to 8192
+    _setmaxstdio(8192);
 #endif
 
 #ifdef __APPLE__